import { ArDateMasks as r, ArDropdownVariants as t, ArLabelValueVariants as e, ArWebPageLayout as a } from "../types/enums.js";
const s = {
  ATOMS: {
    meta: {
      label: "Foundational",
      description: "Basic components that constitute more sophisticated ones"
    },
    components: [
      {
        name: "Accordion",
        props: [
          "classes",
          "variant",
          "data",
          "isRemovable",
          "firstExpanded",
          "appearance"
        ],
        variants: {
          variant: ["limited", "free"],
          appearance: ["stacked", "flat"],
          isRemovable: [!0, !1],
          firstExpanded: [!0, !1]
        }
      },
      {
        name: "AdvancedColorPicker",
        props: []
      },
      {
        name: "Alert",
        props: ["classes", "position", "type", "message", "closeable"],
        variants: {
          position: [
            "top-left",
            "top-right",
            "bottom-left",
            "bottom-right",
            "top-center",
            "bottom-center"
          ],
          type: ["success", "warning", "error", "information"],
          closeable: [!0, !1]
        }
      },
      {
        name: "Badge",
        props: ["size", "text", "type", "shadow"],
        variants: {
          size: ["small", "medium", "large"],
          type: ["inprogress", "complete", "deferred", "atrisk"],
          shadow: [!0, !1]
        }
      },
      {
        name: "Breadcrumb",
        props: [],
        variants: {},
        uses: [{ name: "Button", hierarchy: "ATOMS" }]
      },
      {
        name: "BrowserIncompatibility",
        props: [],
        variants: {},
        uses: [
          { name: "Alert", hierarchy: "ATOMS" },
          { name: "Icon", hierarchy: "ATOMS" }
        ]
      },
      {
        name: "Button",
        props: ["size", "variant", "icon"],
        variants: {
          size: ["xsmall", "small", "medium", "large"],
          variant: [
            "primary",
            "secondary",
            "tertiary",
            "danger",
            "warning",
            "success",
            "info",
            "dark",
            "light",
            "link",
            "link-native",
            "link-hover"
          ],
          content: ["Click me"],
          preIcon: ["io.IoMdHelp", "fa.FaSearch"],
          postIcon: ["io.IoMdHelp", "fa.FaCheckSquare"]
        }
      },
      {
        name: "Calendar",
        props: ["startDate", "minDate", "maxDate", "hasTimeControls"],
        variants: {
          hasTimeControls: [!0, !1],
          miniMode: [!0, !1],
          allowEventSetting: [!0, !1]
        },
        uses: [
          { name: "Button", hierarchy: "ATOMS" },
          { name: "Badge", hierarchy: "ATOMS" },
          { name: "Dropdown", hierarchy: "ATOMS" },
          { name: "Popover", hierarchy: "ATOMS" },
          { name: "SegmentedControl", hierarchy: "ATOMS" },
          { name: "TextInput", hierarchy: "ATOMS" },
          { name: "TimeInput", hierarchy: "ATOMS" },
          { name: "TextArea", hierarchy: "ATOMS" },
          { name: "Toggle", hierarchy: "ATOMS" }
        ]
      },
      {
        name: "Carousel",
        props: [],
        variants: {}
      },
      {
        name: "Checkbox",
        props: ["id", "label", "type", "onChange"],
        variants: {
          type: ["TOGGLE", "CHECKBOX"]
        },
        uses: [{ name: "Toggle", hierarchy: "ATOMS" }]
      },
      {
        name: "ColorPicker",
        props: ["id", "label", "onChange", "value"],
        variants: {
          label: ["Click"]
        }
      },
      {
        name: "ContextMenu",
        type: "HOC",
        children: ["bg"],
        props: [],
        variants: {},
        test: { background: "Balloon" },
        uses: [
          { name: "InlineMenu", hierarchy: "ATOMS" },
          { name: "List", hierarchy: "ATOMS" }
        ]
      },
      {
        name: "DateInput",
        props: [],
        variants: {}
      },
      {
        name: "DatePicker",
        props: ["id", "label"],
        variants: {
          label: ["Date"],
          allowEventSetting: [!0, !1]
        },
        uses: [
          { name: "Calendar", hierarchy: "ATOMS" },
          { name: "Button", hierarchy: "ATOMS" },
          { name: "Dropdown", hierarchy: "ATOMS" },
          { name: "Popover", hierarchy: "ATOMS" },
          { name: "SegmentedControl", hierarchy: "ATOMS" },
          { name: "TextInput", hierarchy: "ATOMS" },
          { name: "TimeInput", hierarchy: "ATOMS" },
          { name: "TextArea", hierarchy: "ATOMS" },
          { name: "Toggle", hierarchy: "ATOMS" }
        ]
      },
      {
        name: "DateRangePicker",
        props: ["id", "label"],
        variants: {
          label: ["Date Range"],
          closeOnEndSelect: [!0, !1],
          mask: [r.LONGDATE, r.SHORTDATE]
        },
        uses: [
          { name: "Calendar", hierarchy: "ATOMS" },
          { name: "Button", hierarchy: "ATOMS" },
          { name: "Dropdown", hierarchy: "ATOMS" },
          { name: "Popover", hierarchy: "ATOMS" },
          { name: "SegmentedControl", hierarchy: "ATOMS" },
          { name: "TextInput", hierarchy: "ATOMS" },
          { name: "TimeInput", hierarchy: "ATOMS" },
          { name: "TextArea", hierarchy: "ATOMS" },
          { name: "Toggle", hierarchy: "ATOMS" }
        ]
      },
      {
        name: "Dropdown",
        props: ["isMultiSelect", "hasBorder", "showCheckBoxes"],
        variants: {
          isMultiSelect: [!0, !1],
          hasBorder: [!0, !1],
          showCheckBoxes: [!0, !1],
          variant: [
            t.SELECTIONSASLINKS,
            t.SELECTIONSASPILLS
          ],
          hideDropdownMarker: [!0, !1],
          isDisabled: [!0, !1],
          version: ["v1", "v2"]
        },
        uses: [
          { name: "List", hierarchy: "ATOMS" },
          { name: "Popover", hierarchy: "ATOMS" },
          { name: "PopoverV2", hierarchy: "ATOMS" },
          { name: "Button", hierarchy: "ATOMS" },
          { name: "Pillbox", hierarchy: "ATOMS" },
          { name: "Pill", hierarchy: "ATOMS" },
          { name: "Portal", hierarchy: "MOLECULES" }
        ]
      },
      {
        name: "PickerRange",
        props: [],
        variants: {}
      },
      {
        name: "DetailsPanel",
        props: [],
        variants: {}
      },
      {
        name: "Dialog",
        props: [],
        variants: {}
      },
      {
        name: "FacetedFilter",
        props: [],
        variants: {}
      },
      {
        name: "InlineMenu",
        props: [],
        test: { background: "Balloon" },
        variants: {},
        uses: [{ name: "List", hierarchy: "ATOMS" }]
      },
      {
        name: "Icon",
        props: [
          "src",
          "size",
          "classes",
          "containerClasses",
          "height",
          "width"
        ],
        variants: {
          src: ["ai/AiFillAccountBook", "ai/AiFillCaretUp"],
          size: ["1rem", "5rem", "10rem", "64px", "15%"],
          color: ["red", "green", "purple", "#3538f6", "rgb(255, 90, 23)"]
        }
      },
      {
        name: "Image",
        props: ["image", "alt", "title"],
        variants: {
          image: ["https://picsum.photos/200/300"],
          flipHorizontal: [!0, !1],
          flipVertical: [!0, !1],
          rotateBy: [30, -75],
          opacity: [0.3, 0.7],
          brightness: [0.6, 2.5],
          contrast: [0.6, 2.5],
          saturate: [0.6, 2.5],
          blur: [2, 10],
          grayscale: [0.3, 0.7],
          sepia: [0.3, 0.7],
          isBackground: [!0, !1],
          fill: [!0, !1],
          preserveAspectRatio: [!0, !1]
        }
      },
      {
        name: "LabelValue",
        props: [],
        variants: {
          variant: [
            e.FLAT,
            e.STACKED,
            e.FLATBOXED,
            e.STACKBOXED
          ]
        }
      },
      {
        name: "LayoutGenerator",
        props: [],
        variants: {
          variant: [
            a.TWOCOL,
            a.THREECOL,
            a.TABBED,
            a.STACKED,
            a.HEROLINEARCONTENTBLOCKS,
            a.HEROSTAGGEREDARCONTENTBLOCKS,
            a.HEROSTAGGEREDREVERSEDARCONTENTBLOCKS,
            a.GRID,
            a.FULL,
            a.CAROUSEL,
            a.CARD,
            a.SPLIT,
            a.CUSTOM
          ],
          demoChildCount: [1, 2, 3, 5, 10, 17, 20, 28],
          hasHeader: [!0, !1],
          hasFooter: [!0, !1],
          hasDrawer: [!0, !1],
          hasSidepanel: [!0, !1]
        }
      },
      {
        name: "LearnLink",
        props: [],
        variants: {}
      },
      {
        name: "Link",
        props: [],
        variants: {}
      },
      {
        name: "List",
        props: ["showCheckBoxes", "isMultiSelect"],
        variants: {
          showCheckBoxes: [!0, !1],
          isMultiSelect: [!0, !1],
          variant: ["link", "flat"]
        },
        uses: [{ name: "Button", hierarchy: "ATOMS" }]
      },
      {
        name: "Modal",
        props: [],
        variants: {
          show: [!0, !1],
          isSticky: [!0, !1]
        },
        uses: [
          { name: "Button", hierarchy: "ATOMS" },
          { name: "Portal", hierarchy: "MOLECULES" }
        ]
      },
      {
        name: "Notification",
        props: [],
        variants: {}
      },
      {
        name: "NumericStepper",
        props: [],
        variants: {}
      },
      {
        name: "Pagination",
        props: ["data", "maxPillsToShow"],
        variants: {
          maxPillsToShow: [3, 5, 10]
        }
      },
      {
        name: "Picklist",
        props: [],
        variants: {}
      },
      {
        name: "Pill",
        props: [],
        variants: {}
      },
      {
        name: "Pillbox",
        props: [],
        variants: {}
      },
      {
        name: "Popover",
        type: "HOC",
        children: ["anchor", "popover"],
        props: ["position", "trigger"],
        variants: {
          position: [
            "auto",
            "left",
            "right",
            "top",
            "bottom",
            "left-top",
            "left-center",
            "left-bottom",
            "right-top",
            "right-center",
            "right-bottom",
            "top-left",
            "top-center",
            "top-right",
            "bottom-left",
            "bottom-center",
            "bottom-right"
          ],
          trigger: ["click", "hover"],
          version: ["v1", "v2"],
          hideMarker: [!0, !1],
          popAtPointer: [!0, !1],
          animation: ["expand-shrink", "fade"],
          preserveMarkerSpace: [!0, !1]
        },
        uses: [
          { name: "Button", hierarchy: "ATOMS" },
          { name: "PopoverV1", hierarchy: "ATOMS" },
          { name: "PopoverV2", hierarchy: "ATOMS" },
          { name: "Portal", hierarchy: "MOLECULES" }
        ]
      },
      {
        name: "Loader",
        props: ["type", "label", "size"],
        variants: {
          size: ["small", "regular", "large"],
          label: ["Loading Users...", "Submitting Report..."],
          type: ["bar", "circle", "custom", "shapes"]
        }
      },
      {
        name: "ProgressIndicator",
        props: [],
        variants: {}
      },
      {
        name: "ProgressStepper",
        props: [],
        variants: {}
      },
      {
        name: "Radio",
        props: [],
        variants: {}
      },
      {
        name: "SearchField",
        props: [],
        variants: {},
        uses: [
          { name: "TypeAhead", hierarchy: "ATOMS" },
          { name: "TextInput", hierarchy: "ATOMS" },
          { name: "LoadableIcon", hierarchy: "ATOMS" },
          { name: "Loader", hierarchy: "ATOMS" }
        ]
      },
      {
        name: "SecondaryNavigation",
        props: [],
        variants: {}
      },
      {
        name: "SegmentedControl",
        props: [],
        variants: {}
      },
      {
        name: "Select",
        props: [],
        variants: {}
      },
      {
        name: "SelectionPill",
        props: ["classes", "context", "data", "onClick", "size"],
        variants: {
          size: ["small", "medium", "large"]
        }
      },
      {
        name: "Slider",
        props: [],
        variants: {}
      },
      {
        name: "Splitter",
        props: [],
        variants: {}
      },
      {
        name: "Swiper",
        props: [],
        variants: {}
      },
      {
        name: "Tab",
        props: [
          "label",
          "data",
          "deletable",
          "id",
          "isActive",
          "onSelect",
          "size",
          "variant"
        ],
        variants: {
          deletable: [!0, !1],
          isActive: [!0, !1],
          size: ["compact", "comfortable"],
          variant: ["classic", "modern"]
        }
      },
      {
        name: "TabBar",
        props: ["activeId", "data", "onTabChanged", "size", "variant"],
        variants: {
          size: ["compact", "comfortable"],
          variant: ["classic", "modern"]
        },
        uses: [{ name: "Tab", hierarchy: "ATOMS" }]
      },
      {
        name: "Table",
        props: [],
        variants: {
          layout: ["comfortable", "compact", "normal"]
        }
      },
      {
        name: "Tag",
        props: [],
        variants: {}
      },
      {
        name: "TextArea",
        props: [],
        variants: {}
      },
      {
        name: "TreeList",
        props: ["data", "firstExpanded", "noSearch", "title", "onItemSelect"],
        variants: {},
        uses: [
          { name: "SearchField", hierarchy: "ATOMS" },
          { name: "TextInput", hierarchy: "ATOMS" }
        ]
      },
      {
        name: "Mask",
        props: [],
        variants: {}
      },
      {
        name: "TextInput",
        props: ["type", "label", "placeholder", "labelPlacement"],
        variants: {
          type: [
            "text",
            "password",
            "file",
            "radio",
            "color",
            "checkbox",
            "range",
            "date"
          ],
          label: ["Username", !1],
          placeholder: ["Address"],
          labelPlacement: ["left", "top", "right", "bottom"],
          subtitle: [
            "This is a one time question and is used to tailer your experience"
          ],
          size: ["small", "large"],
          action: [!0, !1]
        }
      },
      {
        name: "TimeEntry",
        props: [],
        variants: {}
      },
      {
        name: "Toggle",
        props: [],
        variants: {}
      },
      {
        name: "Toolbar",
        props: [],
        variants: {}
      },
      {
        name: "Tooltip",
        props: [],
        variants: {}
      },
      {
        name: "TypeAhead",
        props: [],
        variants: {
          isMultiSelect: [!0, !1],
          value: ["Test1"],
          inputValue: ["st1", "tes"],
          assistiveContent: ["Provide input to determise project structure"],
          outsourceMultiSelections: [!0, !1]
        },
        uses: [
          { name: "TextInput", hierarchy: "ATOMS" },
          { name: "LoadableIcon", hierarchy: "ATOMS" },
          { name: "Pillbox", hierarchy: "ATOMS" },
          { name: "Pill", hierarchy: "ATOMS" }
        ]
      },
      {
        name: "Uploader",
        props: [],
        variants: {}
      },
      {
        name: "Widget",
        props: ["header", "content"],
        variants: {}
      },
      {
        name: "Wizard",
        props: [
          "stages",
          "activeStage",
          "onStageChange",
          "onComplete",
          "onCancel"
        ],
        variants: {
          navigationType: [
            "standard",
            "overlay",
            "overlay-prominent",
            "external"
          ],
          title: ["Add User", "Create Project"],
          hideStatusBar: [!0, !1]
        },
        uses: [
          { name: "Button", hierarchy: "ATOMS" },
          { name: "LoadableIcon", hierarchy: "ATOMS" }
        ]
      },
      {
        name: "WizardModal",
        variants: {
          hideStatusBar: [!0, !1],
          show: [!0, !1],
          isSticky: [!0, !1]
        },
        uses: [
          { name: "Button", hierarchy: "ATOMS" },
          { name: "LoadableIcon", hierarchy: "ATOMS" },
          { name: "Modal", hierarchy: "ATOMS" },
          { name: "Wizard", hierarchy: "ATOMS" },
          { name: "Portal", hierarchy: "MOLECULES" }
        ]
      }
    ]
  },
  MOLECULES: {
    meta: {
      label: "Features, pages, use cases",
      description: "Use these components for special cases like about us section, blog etc."
    },
    components: [
      {
        name: "AboutUs",
        props: [],
        variants: {}
      },
      {
        name: "Application",
        props: [],
        variants: {}
      },
      {
        name: "Banner",
        props: [],
        variants: {}
      },
      {
        name: "Benefits",
        props: [],
        variants: {}
      },
      {
        name: "Blog",
        props: [],
        variants: {}
      },
      {
        name: "Brands",
        props: [],
        variants: {}
      },
      {
        name: "Breadcrumbs",
        props: [],
        variants: {}
      },
      {
        name: "CTA",
        props: [],
        variants: {}
      },
      {
        name: "Card",
        props: [],
        variants: {}
      },
      {
        name: "Careers",
        props: [],
        variants: {}
      },
      {
        name: "Contact",
        props: [],
        variants: {}
      },
      {
        name: "Content",
        props: [],
        variants: {}
      },
      {
        name: "Cookies",
        props: [],
        variants: {}
      },
      {
        name: "Dashboard",
        props: [],
        variants: {}
      },
      {
        name: "Download",
        props: [],
        variants: {}
      },
      {
        name: "Ecomm_Orders",
        props: [],
        variants: {}
      },
      {
        name: "Ecomm_Products",
        props: [],
        variants: {}
      },
      {
        name: "Empty",
        props: [],
        variants: {}
      },
      {
        name: "FAQ",
        props: [],
        variants: {}
      },
      {
        name: "Features",
        props: [],
        variants: {}
      },
      {
        name: "Footer",
        props: [],
        variants: {}
      },
      {
        name: "Form",
        props: [],
        variants: {}
      },
      {
        name: "Gallery",
        props: [],
        variants: {}
      },
      {
        name: "GraphTiles",
        props: [],
        variants: {}
      },
      {
        name: "Graph",
        props: [],
        variants: {}
      },
      {
        name: "HTTPCode",
        props: [],
        variants: {}
      },
      {
        name: "Hero",
        props: [],
        variants: {}
      },
      {
        name: "HowItWorks",
        props: [],
        variants: {}
      },
      {
        name: "InstaPhotos",
        props: [],
        variants: {}
      },
      {
        name: "Integrations",
        props: [],
        variants: {}
      },
      {
        name: "LogoClouds",
        props: [],
        variants: {}
      },
      {
        name: "Newsletter",
        props: [],
        variants: {}
      },
      {
        name: "Notifications",
        props: [],
        variants: {}
      },
      {
        name: "pagination",
        props: [],
        variants: {}
      },
      {
        name: "portfolio",
        props: [],
        variants: {}
      },
      {
        name: "Pricing",
        props: [],
        variants: {}
      },
      {
        name: "ProductInfo",
        props: [],
        variants: {}
      },
      {
        name: "Projects",
        props: [],
        variants: {}
      },
      {
        name: "Reviews",
        props: [],
        variants: {}
      },
      {
        name: "RichText",
        props: [],
        variants: {}
      },
      {
        name: "Services",
        props: [],
        variants: {}
      },
      {
        name: "SignInUp",
        props: [],
        variants: {}
      },
      {
        name: "Snackbar",
        props: [],
        variants: {}
      },
      {
        name: "Stats",
        props: [],
        variants: {}
      },
      {
        name: "Steps",
        props: [],
        variants: {}
      },
      {
        name: "Table",
        props: [],
        variants: {}
      },
      {
        name: "Team",
        props: [],
        variants: {}
      },
      {
        name: "Testimonials",
        props: [],
        variants: {}
      },
      {
        name: "Toast",
        props: [],
        variants: {}
      },
      {
        name: "Users",
        props: [],
        variants: {}
      }
    ]
  }
};
export {
  s as default
};
